MethodChannelFlutterV2ray class

An implementation of FlutterV2rayPlatform that uses method channels.

Inheritance

Constructors

MethodChannelFlutterV2ray()

Properties

eventChannel → EventChannel
final
hashCode → int
The hash code for this object.
no setterinherited
methodChannel → MethodChannel
The method channel used to interact with the native platform.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

getConnectedServerDelay(String url) → Future<int>
override
getCoreVersion() → Future<String>
override
getServerDelay({required String config, required String url}) → Future<int>
override
initializeV2Ray({required void onStatusChanged(V2RayStatus status), required String notificationIconResourceType, required String notificationIconResourceName}) → Future<void>
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
requestPermission() → Future<bool>
override
startV2Ray({required String remark, required String config, required String notificationDisconnectButtonName, List<String>? blockedApps, List<String>? bypassSubnets, bool proxyOnly = false}) → Future<void>
override
stopV2Ray() → Future<void>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited